<?php
/**
 *
 * @package phpBB Extension - Anti Adblock
 * @copyright (c) 2019 Picaron
 * @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
 *
 */

namespace pikaron\antiadblock\acp;

/**
* @package acp
*/
class acp_antiadblock_module
{
	/** @var \phpbb\config\config $config */
	protected $config;

	/** @var \phpbb\config\db_text */
	protected $config_text;

	/** @var $request \phpbb\request\request_interface */
	protected $request;

	/** @var \phpbb\language\language */
	protected $language;

	/** @var \phpbb\user $user */
	protected $user;

	/** @var \phpbb\template\template */
	protected $template;

	/** @var phpbb\log\log_interface */
	protected $phpbb_log;

	/** @var string Custom form action */
	public $u_action;

	/** @var string */
	public $new_config = array();

	/** @var string */
	public $tpl_name;

	/** @var string */
	public $page_title;

	/**
	 * ACP module constructor.
	 *
	 * @return void
	 */
	public function __construct()
	{
		global $phpbb_container;

		$this->config			= $phpbb_container->get('config');
		$this->config_text		= $phpbb_container->get('config_text');
		$this->request			= $phpbb_container->get('request');
		$this->language			= $phpbb_container->get('language');
		$this->user				= $phpbb_container->get('user');
		$this->template			= $phpbb_container->get('template');
		$this->phpbb_log		= $phpbb_container->get('log');
	}

	public function main($id, $mode)
	{
		$submit = $this->request->is_set_post('submit');

		$form_key = 'acp_antiadblock';
		add_form_key($form_key);

		// Asign inicial vars
		$display_vars_ini = array(
			'title' => 'ACP_ANTIADBLOCK',
			'vars'	=> array(
				'legend' => 'GENERAL_OPTIONS',
				'antiadblock_active'		=> array('lang' => 'ACP_ANTIADBLOCK_ACTIVE', 'validate' => 'bool', 'type' => 'radio:yes_no', 'explain' => false),
				'antiadblock_cookie'		=> array('lang' => 'ACP_ANTIADBLOCK_COOKIE', 'validate' => 'int:5:800', 'type' => 'number:5:1800', 'explain' => true, 'append' => '	 ' . $this->language->lang('ACP_UNI_DELAY')),
				'antiadblock_banner'		=> array('lang' => 'ACP_DISPLAY_ANTIADBLOCK_SHOW', 'validate' => 'int', 'type' => 'select', 'function' => array($this, 'antiadblock_take_banner'), 'explain' => false),
				'antiadblock_can_closed'	=> array('lang' => 'ACP_ANTIADBLOCK_CAN_CLOSED', 'validate' => 'bool', 'type' => 'radio:yes_no', 'explain' => true),
				'antiadblock_delay'			=> array('lang' => 'ACP_DISPLAY_ANTIADBLOCK_TIME', 'validate' => 'int:1:20', 'type' => 'number:1:20', 'explain' => true, 'append' => '	' . $this->language->lang('ACP_UNI_DELAY')),
			)
		);

		// Load inicial vars
		$this->new_config['antiadblock_active']		= $this->config['antiadblock_active'];
		$this->new_config['antiadblock_cookie']		= $this->config['antiadblock_cookie'];
		$this->new_config['antiadblock_banner']		= $this->config['antiadblock_banner'];
		$this->new_config['antiadblock_can_closed'] = $this->config['antiadblock_can_closed'];
		$this->new_config['antiadblock_delay']		= $this->config['antiadblock_delay'];

		// Loading defined languages
		$languages		= array();
		$languages_ini	= !empty($this->config['antiadblock_languages']) ? json_decode($this->config['antiadblock_languages'], true) : array();

		// First position lang of user
		if (in_array($this->language->get_used_language(), $languages_ini))
		{
			$languages[] = $this->language->get_used_language();
		}

		foreach ($languages_ini as $ii)
		{
			if ($ii != $this->language->get_used_language())
			{
				$languages[] = $ii;
			}
		}

		$display_vars_lng = array('title' => 'ACP_ANTIADBLOCK');
		foreach ($languages as $i)
		{
			// Asign language vars
			$display_vars_lng['vars']['legend_' . $i] = $this->language->lang('ACP_ANTIADBLOCK_PACK_LANGUAGE', $i);

			if ($i != 'en') // English can not be eliminated
			{
				$display_vars_lng['vars']['antiadblock_delete_' . $i] = array('lang' => 'ACP_ANTIADBLOCK_DELETE', 'validate' => 'bool', 'type' => 'radio:yes_no', 'explain' => true);
			}

			$display_vars_lng['vars']['antiadblock_ini_' . $i]		  = array('lang' => 'ACP_ANTIADBLOCK_REQUEST_INI', 'validate' => 'antiadblock_ini_' . $i, 'type' => 'textarea:5:70', 'explain' => true);
			$display_vars_lng['vars']['antiadblock_disable_' . $i]	  = array('lang' => 'ACP_ANTIADBLOCK_REQUEST_DISABLE', 'validate' => 'antiadblock_disable_' . $i, 'type' => 'textarea:5:70', 'explain' => true);
			$display_vars_lng['vars']['antiadblock_help_' . $i]		  = array('lang' => 'ACP_ANTIADBLOCK_TAKE_HELP', 'validate' => 'string', 'type' => 'text:72:250', 'explain' => true);
			$display_vars_lng['vars']['antiadblock_help_url_' . $i]	  = array('lang' => 'ACP_ANTIADBLOCK_TAKE_HELP_URL', 'validate' => 'string', 'type' => 'url:72:250', 'explain' => true);

			// Load language vars
			$this->new_config['antiadblock_delete_' . $i]	= 0;
			$this->new_config['antiadblock_ini_' . $i]		= $this->config_text->get('antiadblock_ini_' . $i);
			$this->new_config['antiadblock_disable_' . $i]	= $this->config_text->get('antiadblock_disable_' . $i);
			$this->new_config['antiadblock_help_' . $i]		= $this->config_text->get('antiadblock_help_' . $i);
			$this->new_config['antiadblock_help_url_' . $i] = $this->config_text->get('antiadblock_help_url_' . $i);
		}

		// New language
		// Asign language vars
		$display_vars_new['vars']['legend_new']					= $this->language->lang('ACP_ANTIADBLOCK_PACK_LANGUAGE', $this->language->lang('ACP_ANTIADBLOCK_PACK_LANGUAGE_NEW'));
		$display_vars_new['vars']['antiadblock_name_new']		= array('lang' => 'ACP_ANTIADBLOCK_NAME_NEW', 'validate' => 'string', 'type' => 'text:12:12', 'explain' => true);
		$display_vars_new['vars']['antiadblock_ini_new']		= array('lang' => 'ACP_ANTIADBLOCK_REQUEST_INI', 'validate' => 'antiadblock_ini_new', 'type' => 'textarea:5:70', 'explain' => true);
		$display_vars_new['vars']['antiadblock_disable_new']	= array('lang' => 'ACP_ANTIADBLOCK_REQUEST_DISABLE', 'validate' => 'antiadblock_disable_new', 'type' => 'textarea:5:70', 'explain' => true);
		$display_vars_new['vars']['antiadblock_help_new']		= array('lang' => 'ACP_ANTIADBLOCK_TAKE_HELP', 'validate' => 'string', 'type' => 'text:72:250', 'explain' => true);
		$display_vars_new['vars']['antiadblock_help_url_new']	= array('lang' => 'ACP_ANTIADBLOCK_TAKE_HELP_URL', 'validate' => 'string', 'type' => 'url:72:250', 'explain' => true);

		$config_data	= $this->request->variable('config', array('' => ''), true);
		$my_cfg_array	= sizeof($config_data) ? $config_data : $this->new_config;
		$error			= array();

		// Any new language???
		if (isset($my_cfg_array['antiadblock_name_new']) && $my_cfg_array['antiadblock_name_new'] != '')
		{
			$new_language = trim(str_replace(' ', '_', $my_cfg_array['antiadblock_name_new']));
			if (in_array($new_language, $languages))
			{
				$error[] = $this->language->lang('ACP_ANTIADBLOCK_LANGUAGE_EXIST', $new_language);
			}

			$total = array_merge($display_vars_lng['vars'] + $display_vars_new['vars'] + $display_vars_ini['vars']);
		}
		else
		{
			$total = array_merge($display_vars_lng['vars'] + $display_vars_ini['vars']);
		}

		// We validate the complete config and config_text if whished
		validate_config_vars($total, $my_cfg_array, $error);

		if ($submit && !check_form_key($form_key))
		{
			$error[] = $this->language->lang('FORM_INVALID');
		}

		// Do not write values if there is an error
		if (sizeof($error))
		{
			$submit = false;
		}

		// Save all vars
		if ($submit)
		{
			// Save vars
			foreach ($total as $config_name => $null)
			{
				if (strpos($config_name, 'delete') !== false || strpos($config_name, 'legend') !== false)
				{
					continue;
				}

				if (isset($this->config[$config_name]))
				{
					// Save ini language vars
					$this->config->set($config_name, $my_cfg_array[$config_name]);

				}
				elseif (strpos($config_name, 'new') === false)
				{
					// Save existing language vars
					$this->config_text->set($config_name, $my_cfg_array[$config_name]);

				}
				elseif (strpos($config_name, 'name_new') === false)
				{
					if (isset($new_language) && $new_language != '' && !in_array($new_language, $languages))
					{
						// Save new language vars
						$cad = substr ($config_name, 0, strlen($config_name) - 3);
						$this->config_text->set($cad . $new_language, $my_cfg_array[$config_name]);
					}
				}
			}

			// Save new array languages
			if (isset($new_language) && $new_language != '' && !in_array($new_language, $languages))
			{
				$languages[] = $new_language;
				$this->config->set('antiadblock_languages', json_encode($languages));
			}

			// Delete language
			$languages_no_del	= array('en');	// English can not be eliminated
			$ok_del				= false;

			foreach ($languages as $i)
			{
				if ($i == 'en')	 // English can not be eliminated
				{
					continue;
				}
				if (isset($my_cfg_array['antiadblock_delete_' . $i]) && $my_cfg_array['antiadblock_delete_' . $i] == 1)
				{
					$ok_del = true;
					$this->config_text->delete('antiadblock_ini_' . $i);
					$this->config_text->delete('antiadblock_help_' . $i);
					$this->config_text->delete('antiadblock_help_url_' . $i);
					$this->config_text->delete('antiadblock_disable_' . $i);
				}
				else
				{
					$languages_no_del[] = $i;
				}
			}

			// Save new array languages after deletes
			if ($ok_del)
			{
				$this->config->set('antiadblock_languages', json_encode($languages_no_del));
			}

			// Save log
			$this->phpbb_log->add('admin', $this->user->data['user_id'], $this->user->ip, 'LOG_CONFIG_' . strtoupper($mode));
			trigger_error($this->language->lang('CONFIG_UPDATED') . adm_back_link($this->u_action));
		}

		// Printing subpages
		$this->antiadblock_output_page($display_vars_ini['vars']);
		$this->antiadblock_output_page($display_vars_new['vars']);
		$this->antiadblock_output_page($display_vars_lng['vars']);

		$this->tpl_name	  = 'acp_antiadblock';
		$this->page_title = $display_vars_ini['title'];

		$this->template->assign_vars(array(
			'L_TITLE'					 => $this->language->lang($display_vars_ini['title']),
			'L_TITLE_EXPLAIN'			 => $this->language->lang($display_vars_ini['title'] . '_EXPLAIN'),
			'L_ACP_ANTIADBLOCK_VERSION'	 => $this->language->lang('ACP_ANTIADBLOCK_VERSION'),
			'SLIDE_ANTIADBLOCK_VERSION'	 => isset($this->config['version_antiadblock']) ? $this->config['version_antiadblock'] : false,
			'S_ERROR'					 => sizeof($error) ? true : false,
			'ERROR_MSG'					 => implode('<br /><br />', $error),
			'U_ACTION'					 => $this->u_action
		));
	}

	/**
	 * Printing subpages
	 *
	 * @return string The HTML code
	 * @access public
	 */
	public function antiadblock_output_page($item)
	{
		foreach ($item as $config_key => $vars)
		{
			if (!is_array($vars) && strpos($config_key, 'legend') === false)
			{
				continue;
			}

			if (strpos($config_key, 'legend') !== false)
			{
				$this->template->assign_block_vars('options', array(
					'S_LEGEND'		=> true,
					'LEGEND'		=> ($this->language->lang($vars) !== null) ? $this->language->lang($vars) : $vars)
				);

				continue;
			}
			$type = explode(':', $vars['type']);

			$l_explain = '';
			if ($vars['explain'] != false)
			{
				$l_explain = ($this->language->lang($vars['lang'] . '_EXPLAIN') !== null) ? $this->language->lang($vars['lang'] . '_EXPLAIN') : $vars['explain'];
			}

			$content = build_cfg_template($type, $config_key, $this->new_config, $config_key, $vars);

			if (empty($content))
			{
				continue;
			}

			$this->template->assign_block_vars('options', array(
				'KEY'			=> $config_key,
				'TITLE'			=> $this->language->lang($vars['lang']) !== null ? $this->language->lang($vars['lang']) : $vars['lang'],
				'S_EXPLAIN'		=> $vars['explain'],
				'TITLE_EXPLAIN' => $l_explain,
				'CONTENT'		=> $content,
				)
			);

			unset($item[$config_key]);
		}
	}

	/**
	 * Create options for the antiadblock_banner mode select setting
	 *
	 * @param int	 $selected The current value of the config setting
	 * @return string The HTML option tags
	 * @access public
	 */
	public function antiadblock_take_banner($selected)
	{
		$options = '';
		$options .= '<option value="1"' . ($selected == 1 ? ' selected="selected"' : '') . '>' . $this->language->lang('ACP_ANTIADBLOCK_SCREEN') . '</option>';
		$options .= '<option value="2"' . ($selected == 2 ? ' selected="selected"' : '') . '>' . $this->language->lang('ACP_ANTIADBLOCK_BANNER') . '</option>';
		$options .= '<option value="3"' . ($selected == 3 ? ' selected="selected"' : '') . '>' . $this->language->lang('ACP_ANTIADBLOCK_MESSAGE') . '</option>';
		return $options;
	}
}
