<?php
/**
 *
 * @package phpBB Extension - Anti Adblock
 * @copyright (c) 2019 Picaron
 * @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
 *
 */

namespace pikaron\antiadblock\migrations;

class release_1_2_0 extends \phpbb\db\migration\migration
{

	public function effectively_installed()
	{
		return !empty($this->config['version_antiadblock']);
	}

	/**
	* Assign migration file dependencies for this migration
	*
	* @return array Array of migration files
	* @static
	* @access public
	*/
	static public function depends_on()
	{
		return array('\phpbb\db\migration\data\v320\v320');
	}

	/**
	* Add Anti Adblock data to the database.
	*
	* @return array Array of table data
	* @access public
	*/
	public function update_data()
	{
		$languages = array('es', 'en');
		$data = array(
			array('config.add', array('version_antiadblock', '1.2.0')),
			array('config.add', array('antiadblock_banner', 3)),
			array('config.add', array('antiadblock_can_closed', 0)),
			array('config.add', array('antiadblock_delay', 1)),
			array('config.add', array('antiadblock_cookie', 5)),
			array('config.add', array('antiadblock_active', 1)),
			array('config.add', array('antiadblock_languages', json_encode($languages))),

			// Add ACP extension category
			array('module.add', array(
				'acp',
				'ACP_CAT_DOT_MODS',
				'ACP_ANTIADBLOCK',
			)),

			// Add ACP preferences module
			array('module.add', array(
				'acp',
				'ACP_ANTIADBLOCK',
				array(
					'module_basename'	=> '\pikaron\antiadblock\acp\acp_antiadblock_module',
					'modes'				=> array(
						'antiadblock',
					),
				),
			)),

			// Add permissions
			array('permission.add', array('u_show_antiadblock', true)),
			array('permission.add', array('f_show_antiadblock', false)),

			// Set permissions
			array('permission.permission_set', array('REGISTERED', 'u_show_antiadblock', 'group', true)),
			array('permission.permission_set', array('NEWLY_REGISTERED', 'u_show_antiadblock', 'group', true)),
			array('permission.permission_set', array('BOTS', 'u_show_antiadblock', 'group', false)),
			array('permission.permission_set', array('GUESTS', 'u_show_antiadblock', 'group', true)),

			array('permission.permission_set', array('ROLE_USER_FULL', 'u_show_antiadblock', 'role', true)),
			array('permission.permission_set', array('ROLE_USER_LIMITED', 'u_show_antiadblock', 'role', true)),
			array('permission.permission_set', array('ROLE_USER_NEW_MEMBER', 'u_show_antiadblock', 'role', true)),
			array('permission.permission_set', array('ROLE_USER_NOAVATAR', 'u_show_antiadblock', 'role', true)),
			array('permission.permission_set', array('ROLE_USER_NOPM', 'u_show_antiadblock', 'role', true)),
			array('permission.permission_set', array('ROLE_USER_STANDARD', 'u_show_antiadblock', 'role', true)),

			array('permission.permission_set', array('ROLE_FORUM_BOT', 'f_show_antiadblock', 'role', true)),
			array('permission.permission_set', array('ROLE_FORUM_FULL', 'f_show_antiadblock', 'role', true)),
			array('permission.permission_set', array('ROLE_FORUM_LIMITED', 'f_show_antiadblock', 'role', true)),
			array('permission.permission_set', array('ROLE_FORUM_LIMITED_POLLS', 'f_show_antiadblock', 'role', true)),
			array('permission.permission_set', array('ROLE_FORUM_NEW_MEMBER', 'f_show_antiadblock', 'role', true)),
			array('permission.permission_set', array('ROLE_FORUM_NOACCESS', 'f_show_antiadblock', 'role', true)),
			array('permission.permission_set', array('ROLE_FORUM_ONQUEUE', 'f_show_antiadblock', 'role', true)),
			array('permission.permission_set', array('ROLE_FORUM_POLLS', 'f_show_antiadblock', 'role', true)),
			array('permission.permission_set', array('ROLE_FORUM_READONLY', 'f_show_antiadblock', 'role', true)),
			array('permission.permission_set', array('ROLE_FORUM_STANDARD', 'f_show_antiadblock', 'role', true)),
		);

		// Default text in Spanish
		$text['es']['ini'] = 'Nuestro sitio web muestra anuncios en línea a nuestros visitantes para poder sufragar los gastos de hospedaje.

¡¡¡ Por favor, considere apoyarnos desactivando nuestra Web en su Bloqueador de Anuncios. !!!';
		$text['es']['hel'] = '¿Cómo deshabilitar AdBlock? Click AQUI...';
		$text['es']['url'] = 'https://es.wikihow.com/deshabilitar-AdBlock';
		$text['es']['dis'] = 'DESACTIVE SU ADBLOCKER EN NUESTRA WEB PARA PODER DISFRUTAR DEL CONTENIDO SIN INTERRUPCIONES.';

		// Default text in English
		$text['en']['ini'] = 'Our website shows online advertisements to our visitors to cover the cost of hosting.

Please, consider supporting us by deactivating our Web in your Ad Blocker. !!!';
		$text['en']['hel'] = 'How to disable AdBlock? Click Here...';
		$text['en']['url'] = 'https://www.wikihow.com/Disable-AdBlock';
		$text['en']['dis'] = 'DISABLE YOUR ADBLOCKER ON OUR WEB TO ENJOY THE CONTENT WITHOUT INTERRUPTIONS.';

		foreach ($languages as $i)
		{
			$data[] = array('config_text.add', array('antiadblock_ini_' . $i, $text[$i]['ini']));
			$data[] = array('config_text.add', array('antiadblock_help_' . $i, $text[$i]['hel']));
			$data[] = array('config_text.add', array('antiadblock_help_url_' . $i, $text[$i]['url']));
			$data[] = array('config_text.add', array('antiadblock_disable_' . $i, $text[$i]['dis']));
		}

		return $data;
	}

	public function revert_data()
	{
		return array(
			// Delete config
			array('config.remove', array('version_antiadblock')),
			array('config.remove', array('antiadblock_banner')),
			array('config.remove', array('antiadblock_can_closed')),
			array('config.remove', array('antiadblock_delay')),
			array('config.remove', array('antiadblock_cookie')),
			array('config.remove', array('antiadblock_active')),
			array('config.remove', array('antiadblock_languages')),

			// Delete ACP extension category and preferences module
			array('if', array(
				array('module.exists', array('acp', false, 'ACP_ANTIADBLOCK')),
				array('module.remove', array('acp', false, 'ACP_ANTIADBLOCK')),
			)),

			// Remove permissions
			array('permission.remove', array('u_show_antiadblock')),
			array('permission.remove', array('f_show_antiadblock')),

			// Unset permissions
			array('permission.permission_unset', array('REGISTERED', 'u_show_antiadblock', 'group')),
			array('permission.permission_unset', array('NEWLY_REGISTERED', 'u_show_antiadblock', 'group')),
			array('permission.permission_unset', array('BOTS', 'u_show_antiadblock', 'group')),
			array('permission.permission_unset', array('GUESTS', 'u_show_antiadblock', 'group')),

			array('permission.permission_unset', array('ROLE_USER_FULL', 'u_show_antiadblock', 'role')),
			array('permission.permission_unset', array('ROLE_USER_LIMITED', 'u_show_antiadblock', 'role')),
			array('permission.permission_unset', array('ROLE_USER_NEW_MEMBER', 'u_show_antiadblock', 'role')),
			array('permission.permission_unset', array('ROLE_USER_NOAVATAR', 'u_show_antiadblock', 'role')),
			array('permission.permission_unset', array('ROLE_USER_NOPM', 'u_show_antiadblock', 'role')),
			array('permission.permission_unset', array('ROLE_USER_STANDARD', 'u_show_antiadblock', 'role')),

			array('permission.permission_unset', array('ROLE_FORUM_BOT', 'f_show_antiadblock', 'role')),
			array('permission.permission_unset', array('ROLE_FORUM_FULL', 'f_show_antiadblock', 'role')),
			array('permission.permission_unset', array('ROLE_FORUM_LIMITED', 'f_show_antiadblock', 'role')),
			array('permission.permission_unset', array('ROLE_FORUM_LIMITED_POLLS', 'f_show_antiadblock', 'role')),
			array('permission.permission_unset', array('ROLE_FORUM_NEW_MEMBER', 'f_show_antiadblock', 'role')),
			array('permission.permission_unset', array('ROLE_FORUM_NOACCESS', 'f_show_antiadblock', 'role')),
			array('permission.permission_unset', array('ROLE_FORUM_ONQUEUE', 'f_show_antiadblock', 'role')),
			array('permission.permission_unset', array('ROLE_FORUM_POLLS', 'f_show_antiadblock', 'role')),
			array('permission.permission_unset', array('ROLE_FORUM_READONLY', 'f_show_antiadblock', 'role')),
			array('permission.permission_unset', array('ROLE_FORUM_STANDARD', 'f_show_antiadblock', 'role')),

			// Delete all vars %config_text with custom funtion
			array('custom', array(array($this, 'remove_antiadblock_config_text'))),
		);
	}

	// Delete all %config_text creates in application
	public function remove_antiadblock_config_text()
	{
		$sql = 'DELETE FROM ' . CONFIG_TEXT_TABLE . ' WHERE config_name ' . $this->db->sql_like_expression('antiadblock' . $this->db->get_any_char());
		$result = $this->db->sql_query($sql);
		$this->db->sql_freeresult($result);
	}
}
